#ifndef _CONFIG_H
	#define _CONFIG_H

	/*
	 * CPU Frequency in Hz (16000000, 8000000, 4000000, 2000000, ...)
	 */
	#define F_CPU 8000000

	/*
	 * RS232 Baud Rate
	 */ 
	#define BAUD 2400

	/*
	 * I2C Clock Speed in HZ (400000L, 100000L)
	 */
	#define SCL_CLOCK  500000L


	/*
	 * LCD Configuration
	 */

	#define LCD_MODE_I2C 0
	#define LCD_MODE_HD44780 1
	#define LCD_MODE_KS0073 2


	#define LCD_MODE LCD_MODE_HD44780  /**
										* LCD Mode, Switch between I2C LCD, HD44780 and KS0073
										* LCD_MODE_I2C - I2C LCD (AE T123A from Conrad.at) with I2C PCF 2116 
										* LCD_MODE_HD44780 - LCD with HD44780 chip
										* LCD_MODE_KS0073 - LCD with KS0073 chip
										*/

	#if (LCD_MODE == LCD_MODE_HD44780) || (LCD_MODE == LCD_MODE_KS0073)

	//IF MODE is LCD_MODE_HD44780 or LCD_MODE_KS0073
	#define LCD_LINES           	2			/**< number of visible lines of the display */
	#define LCD_DISP_LENGTH    		16			/**< visibles characters per line of the display */
	#define LCD_LINE_LENGTH  		0x40    	/**< internal line length of the display    */
	#define LCD_START_LINE1  		0x00    	/**< DDRAM address of first char of line 1 */
	#define LCD_START_LINE2  		0x40    	/**< DDRAM address of first char of line 2 */
	#define LCD_START_LINE3  		0x14    	/**< DDRAM address of first char of line 3 */
	#define LCD_START_LINE4  		0x54    	/**< DDRAM address of first char of line 4 */
	#define LCD_WRAP_LINES      	0     		/**< 0: no wrap, 1: wrap at end of visibile line */
	#define LCD_PORT         		PORTB   	/**< port for the LCD lines   */
	#define LCD_DATA0_PORT   		LCD_PORT    /**< port for 4bit data bit 0 */
	#define LCD_DATA1_PORT   		LCD_PORT    /**< port for 4bit data bit 1 */
	#define LCD_DATA2_PORT   		LCD_PORT    /**< port for 4bit data bit 2 */
	#define LCD_DATA3_PORT   		LCD_PORT    /**< port for 4bit data bit 3 */
	#define LCD_DATA0_PIN    		3           /**< pin for 4bit data bit 0  */
	#define LCD_DATA1_PIN    		2           /**< pin for 4bit data bit 1  */
	#define LCD_DATA2_PIN    		1           /**< pin for 4bit data bit 2  */
	#define LCD_DATA3_PIN    		0           /**< pin for 4bit data bit 3  */
	#define LCD_RS_PORT      		PORTD    	/**< port for RS line         */
	#define LCD_RS_PIN       		6           /**< pin  for RS line         */
	#define LCD_RW_PORT      		PORTD 	    /**< port for RW line         */ //NOT CONNECTED IN GEMINI
	#define LCD_RW_PIN       		5           /**< pin  for RW line         */ //BUT EVERYTHING WORKS WITHOUT IT
	#define LCD_E_PORT       		PORTD    	/**< port for Enable line     */
	#define LCD_E_PIN        		7           /**< pin  for Enable line     */

	#elif LCD_MODE == LCD_MODE_I2C

	//IF MODE is I2C
	#define I2C_ADDRESS_LCD 0x74			
	#define LCD_DIRECTION 128
	#define LCD_MODES 4

	#else
		#error DISPLAY MODE NOT SUPPORTED 
	#endif


#endif
