#include "CapInterface.h"
#include "QT1106.h"
#include "LedMix.h"
#include "../blib/default.h"
#include "../blib/timer.h"
#include "../blib/rs232.h"


#define TOUCHKEY_MASK_BUTTON0 B8(01000000)
#define TOUCHKEY_MASK_BUTTON1 B8(00000001)
#define TOUCHKEY_MASK_BUTTON2 B8(00010000)
#define TOUCHKEY_MASK_BUTTON3 B8(00000100)

#define CAPIF_COLOR_TOUCHKEY_PRESSED 	9, 9, 0
#define CAPIF_COLOR_TOUCHKEY_NPRESSED 	0, 0, 9
#define CAPIF_COLOR_TOUCHWHEEL_PRESSED	9, 9, 0
#define CAPIF_COLOR_TOUCHWHEEL_NPRESSED	0, 0, 9


unsigned char capif_touchwheel_pressed = false, capif_touchkeys_state = 0;
char capif_touchwheel_position = -1;
char capif_wheel_position = -1;
char capif_wheel_old_position = -1;


void (*capif_ui_callback)(capInterfaceKey key_identifier, char value);

void capInterfaceInit(void (*ui_callback)(capInterfaceKey, char))
{
	/* Set Callback */
	capif_ui_callback = ui_callback;


	/* Initializing LED multiplexing routine */ 
	ledMixInit();

	ledMixButton(0, CAPIF_COLOR_TOUCHKEY_NPRESSED); //BTN 1
	ledMixButton(1, CAPIF_COLOR_TOUCHKEY_NPRESSED); //BTN 2
	ledMixButton(2, CAPIF_COLOR_TOUCHKEY_NPRESSED); //BTN 3
	ledMixButton(3, CAPIF_COLOR_TOUCHKEY_NPRESSED); //BTN 4

	ledMixWheel(0, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(1, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(2, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(3, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);

	timerInit(1, 300, ledMixInterruptRoutine);	
	
	/* Initialize Quantum QT1106 */
	InitQt1106();
	SetQt1106CommsMode( QT_COMMS_MODE_POLL_ALWAYS, 50 );
	SetQtCommandField (SET_QT_MODE, QT_MODE_FREE_RUN); 	
	SetQtCommandField (SET_QT_SLD, QT_MODE_WHEEL); 
	SetQtCommandField (SET_QT_AKS, QT_AKS_4K_PLUS_3K_PLUS_W_S);//QT_AKS_K_PLUS_W_S 
	SetQtCommandField (SET_QT_RESOLUTION, QT_RESOLUTION_7); 
	SetQtCommandField (SET_QT_DI, QT_DI_6_DETECTS); 
	SetQtCommandField (SET_QT_MOD, QT_MOD_INFINITE);
	ProcessQt1106();
	mSleep(100);
	CommandQt(QT_COMMAND_SET_THRESHOLD, 40);
	mSleep(100);
}

unsigned char capInterfaceHysteresis(char pos1, char pos2)
{
	if(pos2 == -1) //No old pos2
	{
		return 1;
	}
	else if(pos1 - pos2 > 2 || pos2 - pos1 > 2)
	{
		return 1;
	}
	return 0;
}

unsigned char capInterfaceGetActive(unsigned char position)
{
	return (3 - (position/32))%4;
}

unsigned char capInterfaceGetWheelPosition(char position)
{
	if(position == -1)
	{
		return -1;
	}
	else if(position < 128 && position >= 96) //(position < 128 && position >= 104)
	{
		return 0;
	}
	else if(position < 96 && position >= 64) //(position < 104 && position >= 64)
	{
		return 1;
	}
	else if(position < 64 && position >= 32) //(position < 64 && position >= 28)
	{
		return 2;
	}
	else if (position < 32 && position >= 0)//(position < 28 && position >= 0)
	{
		return 3;
	}
	else
	{
		return -1;
	}

}

char capInterfaceCompareWheelPosition(char pos1, char pos2)
{
	if(pos1 == 0 && pos2 == 3)
	{
		return 1;
	}
	else if(pos1 == 3 && pos2 == 0)
	{
		return -1;
	}
	else if(pos1 < pos2)
	{
		return -1;
	}
	else
	{
		return 1;
	}
}

unsigned char capInterfaceWheelPosition(unsigned char position)
{
	if(position == -1)
	{
		capif_wheel_old_position = -1;
	}
	else
	{
		position = capInterfaceGetWheelPosition(position);

		if(capif_wheel_old_position != -1 && position != capif_wheel_old_position)
		{
			capif_ui_callback(CAPIF_WHEEL, capInterfaceCompareWheelPosition(position, capif_wheel_old_position));

			capif_wheel_old_position = position;
		}
	}

}

void capInterfaceMain()
{
	unsigned char TouchStatus;
	unsigned char TouchKeyStates;
	unsigned char TouchWheelPosition;


	TouchStatus = GetQtStatus( QT_FLAG_STATE );
	TouchKeyStates = GetQtStatus( QT_KEY_STATE );
	TouchWheelPosition = GetQtStatus( QT_WHEEL_POSITION );

	if(TouchKeyStates != capif_touchkeys_state)
	{		

		if(TouchKeyStates & TOUCHKEY_MASK_BUTTON2)
		{
			if(!(capif_touchkeys_state & TOUCHKEY_MASK_BUTTON2)) //Key wan't pressed before
			{
 				ledMixButton(2, CAPIF_COLOR_TOUCHKEY_PRESSED);
				capif_ui_callback(CAPIF_KEY_BACK, 0);
			}
		}
		else
		{
			ledMixButton(2, CAPIF_COLOR_TOUCHKEY_NPRESSED);
		}
		if(TouchKeyStates & TOUCHKEY_MASK_BUTTON0)
		{
			if(!(capif_touchkeys_state & TOUCHKEY_MASK_BUTTON0)) //Key wan't pressed before
			{
 				ledMixButton(0, CAPIF_COLOR_TOUCHKEY_PRESSED);
				capif_ui_callback(CAPIF_KEY_OK, 0);
			}
		}
		else
		{
			ledMixButton(0, CAPIF_COLOR_TOUCHKEY_NPRESSED);
		}
		if(TouchKeyStates & TOUCHKEY_MASK_BUTTON3)
		{
			if(!(capif_touchkeys_state & TOUCHKEY_MASK_BUTTON3)) //Key wan't pressed before
			{
 				ledMixButton(3, CAPIF_COLOR_TOUCHKEY_PRESSED);
				capif_ui_callback(CAPIF_KEY_GP2, 0);
			}
		}
		else
		{
			ledMixButton(3, CAPIF_COLOR_TOUCHKEY_NPRESSED);
		}
		if(TouchKeyStates & TOUCHKEY_MASK_BUTTON1)
		{
			if(!(capif_touchkeys_state & TOUCHKEY_MASK_BUTTON1)) //Key wan't pressed before
			{
 				ledMixButton(1, CAPIF_COLOR_TOUCHKEY_PRESSED);
				capif_ui_callback(CAPIF_KEY_GP1, 0);
			}
		}
		else
		{
			ledMixButton(1, CAPIF_COLOR_TOUCHKEY_NPRESSED);
		}

		capif_touchkeys_state = TouchKeyStates;
	}

	if(TouchKeyStates & B8(10000000) && !capif_touchwheel_pressed)
	{
		ledMixWheel(0, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		ledMixWheel(1, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		ledMixWheel(2, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		ledMixWheel(3, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);

		if(TouchWheelPosition != capif_touchwheel_position)
		{
			capif_touchwheel_position = -1;
			capInterfaceWheelPosition(-1);
		}

		capif_touchwheel_pressed = true;			
	}
	else if(!(TouchKeyStates & B8(10000000)) && capif_touchwheel_pressed)
	{
		ledMixWheel(0, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		ledMixWheel(1, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		ledMixWheel(2, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		ledMixWheel(3, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);

		capif_touchwheel_pressed = false;
	}
	
	if(capif_touchwheel_pressed && capInterfaceHysteresis(TouchWheelPosition,capif_touchwheel_position))
	{
		if(capif_touchwheel_position != -1)
		{
			capInterfaceWheelPosition(TouchWheelPosition);
			ledMixWheel(capInterfaceGetWheelPosition(capif_touchwheel_position), CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
		}
		ledMixWheel(capInterfaceGetWheelPosition(TouchWheelPosition), CAPIF_COLOR_TOUCHWHEEL_PRESSED);

		capif_touchwheel_position = TouchWheelPosition;
	}
}

void capInterfaceWheelClear()
{
	ledMixWheel(0, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(1, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(2, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(3, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);	
}

void capInterfaceButtonsClear()
{
	ledMixButton(0, CAPIF_COLOR_TOUCHKEY_NPRESSED);	
	ledMixButton(1, CAPIF_COLOR_TOUCHKEY_NPRESSED);	
	ledMixButton(2, CAPIF_COLOR_TOUCHKEY_NPRESSED);	
	ledMixButton(3, CAPIF_COLOR_TOUCHKEY_NPRESSED);	
}

void capInterfaceBlinkInitialSequence(unsigned char i)
{
	ledMixWheel(i  , CAPIF_COLOR_TOUCHWHEEL_PRESSED);
	ledMixWheel(i+1, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(i+2, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
	ledMixWheel(i+3, CAPIF_COLOR_TOUCHWHEEL_NPRESSED);
}
