#include "iox.h"
#include "../blib/default.h"
#include "../blib/i2c.h"
#include "../blib/timer.h"


/** 
 * @brief 	Set Data Direction Register value of Port A (connected over 16bit io extender)
 * @param 	value	DDR value	
 * @return 	none
 */
void IoxDDRWrite(unsigned char port, unsigned char value)
{	
	i2cRegisterWrite((port & B8(00000010))?IOX_ADDRESS_B:IOX_ADDRESS_A,(port & B8(00000001))?0x01:0x00,~value);	
}

/** 
 * @brief 	Read Data Direction Register value of Port A (connected over 16bit io extender)
 * @param	none
 * @return 	DDR value
 */
unsigned char IoxDDRRead(unsigned char port)
{
	return ~i2cRegisterRead((port & B8(00000010))?IOX_ADDRESS_B:IOX_ADDRESS_A,(port & B8(00000001))?0x01:0x00);
}

/** 
 * @brief 	Set Port Value of Port A (connected over 16bit io extender)
 * @param 	value	DDR value	
 * @return 	none
 */
void IoxPORTWrite(unsigned char port, unsigned char value)
{
	i2cRegisterWrite((port & B8(00000010))?IOX_ADDRESS_B:IOX_ADDRESS_A,(port & B8(00000001))?0x15:0x14,value);	
}

/** 
 * @brief 	Read Port value of Port A (connected over 16bit io extender)
 * @param	none
 * @return 	Port value
 */
unsigned char IoxPORTRead(unsigned char port)
{
	return i2cRegisterRead((port & B8(00000010))?IOX_ADDRESS_B:IOX_ADDRESS_A,(port & B8(00000001))?0x15:0x14);
}

/** 
 * @brief 	Read Pin value of Port A (connected over 16bit io extender)
 * @param	none
 * @return 	Pin value
 */
unsigned char IoxPINRead(unsigned char port)
{
	return i2cRegisterRead((port & B8(00000010))?IOX_ADDRESS_B:IOX_ADDRESS_A,(port & B8(00000001))?0x13:0x12);
}
